@@ -131,7 +131,7 @@ class DmApi:
             return None
 
         # If there are versions, return the first in the list
-        assert resp
+        assert resp is not None
         if 'versions' in resp.json() and len(resp.json()['versions']):
             return resp.json()['versions'][0]
 
@@ -360,7 +360,7 @@ class DmApi:
             if not ret_val.success:
                 return ret_val
 
-            assert resp
+            assert resp is not None
             if resp.status_code in [200]:
                 for item in resp.json()['files']:
                     existing_path_files.append(item['file_name'])
@@ -488,7 +488,7 @@ class DmApi:
             return ret_val
 
         # OK if we get here
-        assert resp
+        assert resp is not None
         with open(local_file, 'wb') as file_handle:
             file_handle.write(resp.content)
         return ret_val
